.. :changelog:

History
-------

0.1.1 (2013-08-30)
++++++++++++++++++

* Fixed error if the Neo4j server dies crashes unexpectedly.
* Added package to `Coveralls <https://coveralls.io>`_.


0.1.0 (2013-08-29)
++++++++++++++++++

* First release on PyPI.